<?php
/**
 * A TestUnitProducer task for crunchers
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2011 - 2014 Cruncher Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class CruncherTestUnitProducerTask extends BaseTask implements Taskable, Visitable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$taskInstance	An instance of a Taskable/Visitable class
	 */
	public final static function createCruncherTestUnitProducerTask () {
		// Get new instance
		$taskInstance = new CruncherTestUnitProducerTask();

		// Return the prepared instance
		return $taskInstance;
	}

	/**
	 * Accepts the visitor to process the visitor
	 *
	 * @param	$visitorInstance	An instance of a Visitor class
	 * @return	void
	 */
	public function accept (Visitor $visitorInstance) {
		// Visit this task
		$visitorInstance->visitTask($this);
	}

	/**
	 * Executes the task
	 *
	 * @return	void
	 */
	public function executeTask () {
		// Get the producer instance
		$producerInstance = ProducerFactory::createProducerInstance('cruncher_test_unit_producer_class', 'test_unit');

		// Get the current cruncher state from registry
		$stateInstance = Registry::getRegistry()->getInstance('cruncher')->getStateInstance();

		// Debug message
		//* DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('TASK[' . __METHOD__ . ':' . __LINE__ . ']: Executing stateInstance=' . $stateInstance->__toString());

		// We can now invoke that state instance and pass our producer instance for generating some test units
		$stateInstance->executeState($producerInstance);
	}
}

// [EOF]
?>
