<?php
/**
 * A WorkUnitFetcher task for crunchers which asks the cruncher to fetch work
 * units or, if enabled in configuration, work on some test units.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2011 - 2014 Cruncher Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class CruncherWorkUnitFetcherTask extends BaseTask implements Taskable, Visitable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$taskInstance	An instance of a Taskable/Visitable class
	 */
	public final static function createCruncherWorkUnitFetcherTask () {
		// Get new instance
		$taskInstance = new CruncherWorkUnitFetcherTask();

		// Return the prepared instance
		return $taskInstance;
	}

	/**
	 * Accepts the visitor to process the visitor
	 *
	 * @param	$visitorInstance	An instance of a Visitor class
	 * @return	void
	 */
	public function accept (Visitor $visitorInstance) {
		// Visit this task
		$visitorInstance->visitTask($this);
	}

	/**
	 * Executes the task
	 *
	 * @return	void
	 */
	public function executeTask () {
		/*
		 * Get the cruncher instance and call a method which should check if
		 * the in-buffer is going to depleted. If so, new WUs are fetched from
		 * network or (if enabled in config) a random test WU is being
		 * generated. This test WU is for developing only or, if you like, to
		 * test your cruncher loop.
		 *
		 * Please report any bugs you encounter to me.
		 */
		Registry::getRegistry()->getInstance('cruncher')->doFetchWorkUnits();
	}
}

// [EOF]
?>
